@@ -2,7 +2,7 @@
 # described in QEX and for the improved version HiQSDR.  To turn on the extended
 # features in HiQSDR, update your FPGA firmware to version 1.1 or later and use use_rx_udp = 2.
 
-import struct, socket
+import struct, socket, math
 import _quisk as QS
 
 from quisk_hardware_model import Hardware as BaseHardware
@@ -112,24 +112,31 @@ class Hardware(BaseHardware):
     elif mode[0:3] == 'IMD':
       self.tx_control |= 0x02
     self.SetTxLevel()
-    self.NewUdpStatus()
   def ChangeBand(self, band):
     # band is a string: "60", "40", "WWV", etc.
     self.band = band
     self.HiQSDR_Connector_X1 &= ~0x0F	# Mask in the last four bits
     self.HiQSDR_Connector_X1 |= self.conf.HiQSDR_BandDict.get(band, 0) & 0x0F
     self.SetTxLevel()
-    self.NewUdpStatus()
   def SetTxLevel(self):
-    if self.vna_count:
-      return
-    elif self.mode[0:4] == 'DGT-':
-      self.tx_level = self.conf.digital_tx_level
-    else:
+    # As tx_level varies from 50 to 200, the output level changes from 263 to 752 mV
+    # So 0 to 255 is 100 to 931, or 1.0 to 9.31; v = 1.0 + 0.0326 * level
+    if not self.vna_count:
       try:
         self.tx_level = self.conf.tx_level[self.band]
       except KeyError:
         self.tx_level = self.conf.tx_level[None]		# The default
+      if self.mode[0:4] == 'DGT-':
+        reduc = self.application.digital_tx_level
+      else:
+        reduc = self.application.tx_level
+      if reduc < 100:				# reduce power by a percentage
+        level = 1.0 + self.tx_level * 0.0326
+        level *= math.sqrt(reduc / 100.0)      # Convert from a power to an amplitude
+        self.tx_level = int((level - 1.0) / 0.0326 + 0.5)
+        if self.tx_level < 0:
+          self.tx_level = 0
+    self.NewUdpStatus()
   def OnButtonRfGain(self, event):
     # The HiQSDR attenuator is five bits: 2, 4, 8, 10, 20 dB
     btn = event.GetEventObject()
