@@ -11,44 +11,46 @@ class BottomWidgets:	# Add extra widgets to the bottom of the screen
     self.config = conf
     self.hardware = hardware
     self.application = app
+    row = gbs.GetRows()			# The next available row
+    numcols = gbs.GetCols()		# The number of columns
     if hasattr(hardware, 'repeaters'):      # Used for my AR8600 config file
       b = app.QuiskPushbutton(frame, None, 'Tune')
       bw, bh = b.GetMinSize()
       b.Enable(0)
-      gbs.Add(b, (4, 0), flag=wx.EXPAND)
+      gbs.Add(b, (row, 0), (1, 2), flag=wx.EXPAND)
       b = app.QuiskPushbutton(frame, None, '')
-      gbs.Add(b, (4, 1), flag=wx.EXPAND)
+      gbs.Add(b, (row, 2), (1, 2), flag=wx.EXPAND)
       b = app.QuiskPushbutton(frame, None, '')
-      gbs.Add(b, (4, 2), flag=wx.EXPAND)
+      gbs.Add(b, (row, 4), (1, 2), flag=wx.EXPAND)
       b = self.btnScanner = app.QuiskCheckbutton(frame, self.OnBtnScanner, text='Scanner', use_right=True)
       self.scan_timer = wx.Timer(b)	# timed events for the scanner
       b.Bind(wx.EVT_TIMER, self.OnTimerEvent)
-      gbs.Add(b, (4, 3), flag=wx.EXPAND)
+      gbs.Add(b, (row, 6), (1, 2), flag=wx.EXPAND)
       b = self.btnNext = app.QuiskPushbutton(frame, self.OnBtnNext, 'Next', True)
-      gbs.Add(b, (4, 4), flag=wx.EXPAND)
+      gbs.Add(b, (row, 8), (1, 2), flag=wx.EXPAND)
       b = app.QuiskCheckbutton(frame, self.OnBtnRptr, text='Rptr')
       b.SetValue(True, True)
-      gbs.Add(b, (4, 5), flag=wx.EXPAND)
+      gbs.Add(b, (row, 10), (1, 2), flag=wx.EXPAND)
       self.swr_label = app.QuiskText(frame, 'Watts 000   SWR 10.1  Zh Ind 22 Cap 33   Freq 28100 (7777)', bh)
-      gbs.Add(self.swr_label, (4, 7), (1, 6), flag=wx.EXPAND)
+      gbs.Add(self.swr_label, (row, 15), (1, 12), flag=wx.EXPAND)
     else:
       b = app.QuiskPushbutton(frame, self.OnAntTuner, 'HiLo')
       bw, bh = b.GetMinSize()
-      gbs.Add(b, (4, 0), flag=wx.EXPAND)
+      gbs.Add(b, (row, 0), (1, 2), flag=wx.EXPAND)
       b = app.QuiskPushbutton(frame, self.OnAntTuner, 'L+')
-      gbs.Add(b, (4, 1), flag=wx.EXPAND)
+      gbs.Add(b, (row, 2), (1, 2), flag=wx.EXPAND)
       b = app.QuiskPushbutton(frame, self.OnAntTuner, 'L-')
-      gbs.Add(b, (4, 2), flag=wx.EXPAND)
+      gbs.Add(b, (row, 4), (1, 2), flag=wx.EXPAND)
       b = app.QuiskPushbutton(frame, self.OnAntTuner, 'C+')
-      gbs.Add(b, (4, 3), flag=wx.EXPAND)
+      gbs.Add(b, (row, 6), (1, 2), flag=wx.EXPAND)
       b = app.QuiskPushbutton(frame, self.OnAntTuner, 'C-')
-      gbs.Add(b, (4, 4), flag=wx.EXPAND)
+      gbs.Add(b, (row, 8), (1, 2), flag=wx.EXPAND)
       b = app.QuiskPushbutton(frame, self.OnAntTuner, 'Save')
-      gbs.Add(b, (4, 5), flag=wx.EXPAND)
+      gbs.Add(b, (row, 10), (1, 2), flag=wx.EXPAND)
       self.swr_label = app.QuiskText(frame, 'Watts 000   SWR 10.1  Zh Ind 22 Cap 33   Freq 28100 (7777)', bh)
-      gbs.Add(self.swr_label, (4, 7), (1, 5), flag=wx.EXPAND)
+      gbs.Add(self.swr_label, (row, 15), (1, 10), flag=wx.EXPAND)
       b = app.QuiskCheckbutton(frame, None, text='')
-      gbs.Add(b, (4, 12), flag=wx.EXPAND)
+      gbs.Add(b, (row, 25), (1, 2), flag=wx.EXPAND)
 #  Example of a horizontal slider:
 #    lab = wx.StaticText(frame, -1, 'Preamp', style=wx.ALIGN_CENTER)
 #    gbs.Add(lab, (5,0), flag=wx.EXPAND)
