@@ -57,7 +57,7 @@ static int graphY;			// Origin of 0 dB for graph data
 static int average_count;		// Number of FFT's to average for graph
 static double graphScale;		// Scale factor for graph
 static complex testtonePhase;		// Phase increment for test tone
-static double audioVolume;		// Audio output level, 0.0 to 1.0
+double quisk_audioVolume;		// Audio output level, 0.0 to 1.0
 static complex tunePhase;		// Phase increment for tuning frequency
 static double cFilterI[MAX_FILTER_SIZE];	// Digital filter coefficients for receive
 static double cFilterQ[MAX_FILTER_SIZE];	// Digital filter coefficients
@@ -703,13 +703,13 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 
 	// Perhaps write sample data to the soundcard output without decimation
 	if (TEST_AUDIO == 1) {		// Copy I channel capture to playback
-		di = 1.e4 * audioVolume;
+		di = 1.e4 * quisk_audioVolume;
 		for (i = 0; i < nSamples; i++)
 			cSamples[i] = creal(cSamples[i]) * di;
 		return nSamples;
 	}
 	else if (TEST_AUDIO == 2) {	// Copy Q channel capture to playback
-		di = 1.e4 * audioVolume;
+		di = 1.e4 * quisk_audioVolume;
 		for (i = 0; i < nSamples; i++)
 			cSamples[i] = cimag(cSamples[i]) * di;
 		return nSamples;
@@ -1029,7 +1029,7 @@ start_agc:
 			is_squelch = 1;
 		}
 		else {
-			agc_level = agcGain * audioVolume;
+			agc_level = agcGain * 0.95;
 #if DEBUG
 			if (is_squelch)
 				printf("open  squelch\n");
@@ -1038,7 +1038,7 @@ start_agc:
 		}
 	}
 	else {
-		agc_level = agcGain * audioVolume;
+		agc_level = agcGain * 0.95;
 	}
 	if (keyupEnvelope < 1.0) {		// raise volume slowly after the key goes up
 		di = 1. / (quisk_sound_state.playback_rate * 5e-3);		// 5 milliseconds
@@ -1055,7 +1055,7 @@ start_agc:
 		for (i = 0; i < nSamples; i++)
 			cSamples[i] *= agc_level;		// apply AGC
 		if (quisk_record_state == PLAYBACK)
-			tmp_playback(cSamples, nSamples, audioVolume);	// replace radio sound
+			tmp_playback(cSamples, nSamples, quisk_audioVolume);	// replace radio sound
 	}
 	return nSamples;
 }
@@ -1632,7 +1632,7 @@ static PyObject * set_squelch(PyObject * self, PyObject * args)
 
 static PyObject * set_volume(PyObject * self, PyObject * args)
 {
-	if (!PyArg_ParseTuple (args, "d", &audioVolume))
+	if (!PyArg_ParseTuple (args, "d", &quisk_audioVolume))
 		return NULL;
 	Py_INCREF (Py_None);
 	return Py_None;
