@@ -108,6 +108,7 @@ extern double quisk_mic_preemphasis;	// Mic preemphasis 0.0 to 1.0; or -1.0
 extern double quisk_mic_clip;			// Mic clipping; try 3.0 or 4.0
 extern int quisk_noise_blanker;			// Noise blanker level, 0 for off
 extern int quisk_sidetoneCtrl;			// sidetone control value 0 to 1000
+extern double quisk_audioVolume;		// volume control for radio sound playback, 0.0 to 1.0
 
 extern PyObject * quisk_set_spot_level(PyObject * , PyObject *);
 extern PyObject * quisk_get_tx_filter(PyObject * , PyObject *);
@@ -150,12 +151,12 @@ int quisk_extern_demod(complex *, int, double);
 void quisk_tmp_microphone(complex *, int);
 
 int  quisk_read_alsa(struct sound_dev *, complex *);
-void quisk_play_alsa(struct sound_dev *, int, complex *, int);
+void quisk_play_alsa(struct sound_dev *, int, complex *, int, double);
 void quisk_start_sound_alsa(struct sound_dev **, struct sound_dev **);
 void quisk_close_sound_alsa(struct sound_dev **, struct sound_dev **);
 
 int  quisk_read_portaudio(struct sound_dev *, complex *);
-void quisk_play_portaudio(struct sound_dev *, int, complex *, int);
+void quisk_play_portaudio(struct sound_dev *, int, complex *, int, double);
 void quisk_start_sound_portaudio(struct sound_dev **, struct sound_dev **);
 void quisk_close_sound_portaudio(void);
 
