@@ -26,7 +26,8 @@ import sys
 # your .quisk_conf.py.
 import quisk_hardware_model as quisk_hardware
 
-# Module for additional widgets (advanced usage).
+# Module for additional widgets (advanced usage).  See n2adr/quisk_widgets.py for an example.
+# import n2adr.quisk_widgets as quisk_widgets
 quisk_widgets = None
 
 # Select the default screen when Quisk starts:
@@ -222,9 +223,14 @@ rx_ip = ""							# Receiver IP address for VFO control
 # For the N2ADR 2010 transceiver described in QEX, and for the improved version HiQSDR,
 # see the sample config file in the hiqsdr package directory, and set these:
 # tx_level sets the transmit level 0 to 255 for each band.  The None band is the default.
-tx_level = {None:120, '60':110}
-# Digital modes use this instead of tx_level, so you can reduce the power.
-digital_tx_level = 20
+# The config screen has a slider 0 to 100% so you can reduce the transmit power.  The sliders
+# only appear if your hardware defines the method SetTxLevel().  The hardware only supports a
+# power adjustment range of 20 dB, so zero is still a small amount of power.
+tx_level = {None:120, '60':110}     # Adjust your power for each band
+# Digital modes reduce power by the percentage on the config screen.
+# The maximum value of the slider is digital_tx_level.
+digital_tx_level = 20		# The slider on the config screen is 20% maximum.
+#
 # If you use the HiQSDR hardware, set these:
 # The HiQSDR_BandDict sets the preselect (4 bits) on the X1 connector.
 HiQSDR_BandDict = {'160':1, '80':2, '40':3, '30':4, '20':5, '15':6, '17':7,
@@ -276,9 +282,9 @@ freq_base = 0
 cwTone = 600
 
 # These options are used by the digital modes that send audio to an external
-# program, and receive audio to transmit.
-# Set Fldigi to USB, XML-RPC control.
+# program, and receive audio to transmit.  Set Fldigi to USB, XML-RPC control.
 digital_xmlrpc_url = "http://localhost:7362"	# URL for control by XML-RPC
+#digital_xmlrpc_url = ""				# Do not poll socket for XML-RPC control
 # Input audio from an external program for use with digital modes.  The input must be
 # stereo at 48000 sps, and you must set mic_sample_rate to 48000 also.
 digital_input_name = ""		# device name for transmit audio
@@ -591,7 +597,7 @@ bandTime = [
 	]
 
 # This is the list of band buttons that Quisk displays, and it should have
-# a length of 12.  Empty buttons can have a null string "" label.
+# a length of 14 or less.  Empty buttons can have a null string "" label.
 # Note that the 60 meter band and the Time band have buttons that support
 # multiple presses.
 bandLabels = ['Audio', '160', '80', ('60',) * 5, '40', '30', '20', '17',
