@@ -6,9 +6,28 @@ from types import *
 # The main script will alter quisk_conf_defaults to include the user's config file.
 import quisk_conf_defaults as conf
 
+def FreqFormatter(freq):	# Format the string or integer frequency by adding blanks
+  freq = int(freq)
+  if freq >= 0:
+    t = str(freq)
+    minus = ''
+  else:
+    t = str(-freq)
+    minus = '- '
+  l = len(t)
+  if l > 9:
+    txt = "%s%s %s %s %s" % (minus, t[0:-9], t[-9:-6], t[-6:-3], t[-3:])
+  elif l > 6:
+    txt = "%s%s %s %s" % (minus, t[0:-6], t[-6:-3], t[-3:])
+  elif l > 3:
+    txt = "%s%s %s" % (minus, t[0:-3], t[-3:])
+  else:
+    txt = minus + t
+  return txt
+
 class FrequencyDisplay(wx.lib.stattext.GenStaticText):
   """Create a frequency display widget."""
-  def __init__(self, frame, gbs, width, height):
+  def __init__(self, frame, width, height):
     wx.lib.stattext.GenStaticText.__init__(self, frame, -1, '3',
          style=wx.ALIGN_CENTER|wx.ST_NO_AUTORESIZE)
     border = 4
@@ -25,8 +44,6 @@ class FrequencyDisplay(wx.lib.stattext.GenStaticText):
     self.height_and_border = h + border * 2
     self.SetBackgroundColour(conf.color_freq)
     self.SetForegroundColour(conf.color_enable)
-    gbs.Add(self, (0, 0), (1, 3),
-       flag=wx.EXPAND | wx.TOP | wx.BOTTOM, border=border)
   def Clip(self, clip):
     """Change color to indicate clipping."""
     if clip:
@@ -36,24 +53,60 @@ class FrequencyDisplay(wx.lib.stattext.GenStaticText):
     self.Refresh()
   def Display(self, freq):
     """Set the frequency to be displayed."""
-    freq = int(freq)
-    if freq >= 0:
-      t = str(freq)
-      minus = ''
-    else:
-      t = str(-freq)
-      minus = '- '
-    l = len(t)
-    if l > 9:
-      txt = "%s%s %s %s %s" % (minus, t[0:-9], t[-9:-6], t[-6:-3], t[-3:])
-    elif l > 6:
-      txt = "%s%s %s %s" % (minus, t[0:-6], t[-6:-3], t[-3:])
-    elif l > 3:
-      txt = "%s%s %s" % (minus, t[0:-3], t[-3:])
-    else:
-      txt = minus + t
+    txt = FreqFormatter(freq)
     self.SetLabel('%s Hz' % txt)
 
+class SliderBoxH:
+  """A horizontal control with a slider and text with a value.  The text must have a %d if display is True."""
+  def __init__(self, parent, text, init, themin, themax, handler, display, pos, width):
+    self.text = text
+    self.handler = handler
+    self.display = display
+    if display:		# Display the slider value
+      t1 = self.text % themin
+      t2 = self.text % themax
+      if len(t1) > len(t2):		# set text size to the largest
+        t = t1
+      else:
+        t = t2
+    else:
+      t = self.text
+    if pos is None:
+      self.text_ctrl = wx.StaticText(parent, -1, t)
+      self.slider = wx.Slider(parent, -1, init, themin, themax)
+    else:
+      self.text_ctrl = wx.StaticText(parent, -1, t, pos=pos)
+      w2, h2 = self.text_ctrl.GetSize()
+      self.slider = wx.Slider(parent, -1, init, themin, themax, (pos[0] + w2, pos[1]), (width - w2, h2))
+    self.slider.Bind(wx.EVT_SCROLL, self.OnScroll)
+    self.OnScroll()
+  def OnScroll(self, event=None):
+    if event:
+      event.Skip()
+      if self.handler:
+        self.handler(event)
+    if self.display:
+      t = self.text % self.slider.GetValue()
+    else:
+      t = self.text
+    self.text_ctrl.SetLabel(t)
+  def GetValue(self):
+    return self.slider.GetValue()
+  def SetValue(self, value):
+    # Set slider visual position; does not call handler
+    self.slider.SetValue(value)
+    self.OnScroll()
+
+class SliderBoxHH(SliderBoxH, wx.BoxSizer):
+  """A horizontal control with a slider and text with a value.  The text must have a %d if display is True."""
+  def __init__(self, parent, text, init, themin, themax, handler, display):
+    wx.BoxSizer.__init__(self, wx.HORIZONTAL)
+    SliderBoxH.__init__(self, parent, text, init, themin, themax, handler, display, None, None)
+    #font = wx.Font(10, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL)
+    #self.text_ctrl.SetFont(font)
+    self.Add(self.text_ctrl, 0, wx.ALIGN_CENTER|wx.FIXED_MINSIZE)
+    self.Add(self.slider, 1, wx.ALIGN_CENTER)
+
 class SliderBoxV(wx.BoxSizer):
   """A vertical box containing a slider and a text heading"""
   # Note: A vertical wx slider has the max value at the bottom.  This is
@@ -646,14 +699,8 @@ class FreqSetter(wx.TextCtrl):
     elif freq > self.fmax:
       freq = self.fmax
     self.butn.SetValue(freq / 1000)
-    v = str(freq)
-    i = len(v)
-    if i > 6:
-      wx.TextCtrl.SetValue(self, "%s %s %s" % (v[0:i-6], v[-6:-3], v[-3:]))
-    elif i > 3:
-      wx.TextCtrl.SetValue(self, "%s %s" % (v[0:i-3], v[-3:]))
-    else:
-      wx.TextCtrl.SetValue(self, v)
+    txt = FreqFormatter(freq)
+    wx.TextCtrl.SetValue(self, txt)
     self.SetBackgroundColour(conf.color_entry)
   def GetValue(self):
     value = wx.TextCtrl.GetValue(self)
