@@ -340,14 +340,14 @@ int quisk_read_sound(void)	// Called from sound thread
 	QuiskPrintTime("  process samples", 0);
 #endif
 	if (Playback.portaudio_index < 0)
-		quisk_play_alsa(&Playback, nSamples, cSamples, 1);
+		quisk_play_alsa(&Playback, nSamples, cSamples, 1, quisk_audioVolume);
 	else
-		quisk_play_portaudio(&Playback, nSamples, cSamples, 1);
+		quisk_play_portaudio(&Playback, nSamples, cSamples, 1, quisk_audioVolume);
 	if (rxMode == 7 || rxMode == 8 || rxMode == 9) {
 		if (DigitalOutput.portaudio_index < 0)
-			quisk_play_alsa(&DigitalOutput, nSamples, cSamples, 0);
+			quisk_play_alsa(&DigitalOutput, nSamples, cSamples, 0, 0.7);
 		else
-			quisk_play_portaudio(&DigitalOutput, nSamples, cSamples, 0);
+			quisk_play_portaudio(&DigitalOutput, nSamples, cSamples, 0, 0.7);
 	}
 	// Perhaps record the speaker audio to a file
 	if (want_record) {
@@ -476,9 +476,9 @@ int quisk_read_sound(void)	// Called from sound thread
 			correct_sample (&MicPlayback, cSamples, mic_count);
 		// play mic samples
 		if (MicPlayback.portaudio_index < 0)
-			quisk_play_alsa(&MicPlayback, mic_count, cSamples, 0);
+			quisk_play_alsa(&MicPlayback, mic_count, cSamples, 0, 1.0);
 		else
-			quisk_play_portaudio(&MicPlayback, mic_count, cSamples, 0);
+			quisk_play_portaudio(&MicPlayback, mic_count, cSamples, 0, 1.0);
 #if DEBUG_MIC == 2
 		quisk_process_samples(cSamples, mic_count);
 #endif
