@@ -427,7 +427,7 @@ int  quisk_read_alsa(struct sound_dev * dev, complex * cSamples)
 }
 
 void quisk_play_alsa(struct sound_dev * dev, int nSamples,
-		complex * cSamples, int report_latency)
+		complex * cSamples, int report_latency, double volume)
 {
 	LPDIRECTSOUNDBUFFER ptBuf = (LPDIRECTSOUNDBUFFER)dev->buffer;
 	DWORD playPos, writePos;	// hardware index into buffer
@@ -535,8 +535,8 @@ void quisk_play_alsa(struct sound_dev * dev, int nSamples,
 		pts = (short *)pt1;	// Start writing at pt1
 		frames = n1 / bytes_per_frame;
 		for (n = 0; n < nSamples && pass < 2; n++) {
-			pts[dev->channel_I] = (short)(creal(cSamples[n]) / 65536);
-			pts[dev->channel_Q] = (short)(cimag(cSamples[n]) / 65536);
+			pts[dev->channel_I] = (short)(volume * creal(cSamples[n]) / 65536);
+			pts[dev->channel_Q] = (short)(volume * cimag(cSamples[n]) / 65536);
 			pts += dev->num_channels;
 			if (--frames <= 0) {
 				pass++;
@@ -550,8 +550,8 @@ void quisk_play_alsa(struct sound_dev * dev, int nSamples,
 		ptl = (int *)pt1;	// Start writing at pt1
 		frames = n1 / bytes_per_frame;
 		for (n = 0; n < nSamples && pass < 2; n++) {
-			ptl[dev->channel_I] = (int)(creal(cSamples[n]));
-			ptl[dev->channel_Q] = (int)(cimag(cSamples[n]));
+			ptl[dev->channel_I] = (int)(volume * creal(cSamples[n]));
+			ptl[dev->channel_Q] = (int)(volume * cimag(cSamples[n]));
 			ptl += dev->num_channels;
 			if (--frames <= 0) {
 				pass++;
@@ -565,8 +565,8 @@ void quisk_play_alsa(struct sound_dev * dev, int nSamples,
 		ptf = (float *)pt1;	// Start writing at pt1
 		frames = n1 / bytes_per_frame;
 		for (n = 0; n < nSamples && pass < 2; n++) {
-			ptf[dev->channel_I] = (creal(cSamples[n]) / CLIP32);
-			ptf[dev->channel_Q] = (cimag(cSamples[n]) / CLIP32);
+			ptf[dev->channel_I] = (volume * creal(cSamples[n]) / CLIP32);
+			ptf[dev->channel_Q] = (volume * cimag(cSamples[n]) / CLIP32);
 			ptf += dev->num_channels;
 			if (--frames <= 0) {
 				pass++;
@@ -597,7 +597,7 @@ void quisk_play_alsa(struct sound_dev * dev, int nSamples,
 
 
 
-void quisk_play_portaudio(struct sound_dev * dev, int j, complex * samp, int i)
+void quisk_play_portaudio(struct sound_dev * dev, int j, complex * samp, int i, double volume)
 {
 }
 
